pitchtools.HarmonicObject
=========================

.. inheritance-diagram:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__hash__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__str__

    Inherited from `__builtin__.object`
